@@ -17,54 +17,31 @@ from copy import copy
 from typing import Any, Callable, Dict, List, Optional
 
 from mitosheet._version import __version__, package_name
-from mitosheet.saved_analyses.schema_utils import \
-    upgrade_saved_analysis_format_to_steps_data
+from mitosheet.saved_analyses.schema_utils import (
+    is_prev_version, upgrade_saved_analysis_format_to_steps_data)
 from mitosheet.saved_analyses.step_upgraders.add_column import \
     upgrade_add_column_1_to_add_column_2
-from mitosheet.saved_analyses.step_upgraders.change_column_dtype import (
-    upgrade_change_column_dtype_1_to_2, upgrade_change_column_dtype_2_to_3,
-    upgrade_change_column_dtype_3_to_4)
-from mitosheet.saved_analyses.step_upgraders.change_column_format import \
-    upgrade_change_column_format_1_to_remove
+from mitosheet.saved_analyses.step_upgraders.change_column_dtype import \
+    upgrade_change_column_dtype_1_to_2
 from mitosheet.saved_analyses.step_upgraders.delete_column import (
     upgrade_delete_column_1_to_2, upgrade_delete_column_2_to_3)
-from mitosheet.saved_analyses.step_upgraders.excel_range_import import (
-    upgrade_excel_range_import_1_to_2, upgrade_excel_range_import_2_to_3,
-    upgrade_excel_range_import_3_to_4, upgrade_excel_range_import_4_to_5,
-    upgrade_excel_range_import_5_to_6)
 from mitosheet.saved_analyses.step_upgraders.filter import (
-    update_filter_column_1_to_filter_column_2, upgrade_filter_column_2_to_3,
-    upgrade_filter_column_3_to_4)
-from mitosheet.saved_analyses.step_upgraders.graph import (
-    upgrade_graph_1_to_2, upgrade_graph_2_to_3, upgrade_graph_3_to_4)
+    update_filter_column_1_to_filter_column_2, upgrade_filter_column_2_to_3, upgrade_filter_column_3_to_4)
 from mitosheet.saved_analyses.step_upgraders.merge import (
-    upgrade_merge_1_to_merge_2, upgrade_merge_2_to_3, upgrade_merge_3_to_4, upgrade_merge_4_to_5)
+    upgrade_merge_1_to_merge_2, upgrade_merge_2_to_3)
 from mitosheet.saved_analyses.step_upgraders.pivot import (
     upgrade_group_1_to_pivot_2, upgrade_pivot_2_to_pivot_3,
-    upgrade_pivot_3_to_4, upgrade_pivot_4_to_5_and_rename,
-    upgrade_pivot_5_to_6, upgrade_pivot_6_to_7, upgrade_pivot_7_to_8,
-    upgrade_pivot_8_to_9)
+    upgrade_pivot_3_to_4, upgrade_pivot_4_to_5_and_rename, upgrade_pivot_5_to_6)
 from mitosheet.saved_analyses.step_upgraders.rename_column import \
     upgrade_rename_column_1_to_2
 from mitosheet.saved_analyses.step_upgraders.reorder_column import \
     upgrade_reorder_column_1_to_2
-from mitosheet.saved_analyses.step_upgraders.set_column_formula import (
-    upgrade_set_column_formula_1_to_2, upgrade_set_column_formula_2_to_3,
-    upgrade_set_column_formula_3_to_4, upgrade_set_column_formula_4_to_5)
-from mitosheet.saved_analyses.step_upgraders.set_dataframe_format import \
-    upgrade_set_dataframe_format_1_to_2
+from mitosheet.saved_analyses.step_upgraders.set_column_formula import \
+    upgrade_set_column_formula_1_to_2
 from mitosheet.saved_analyses.step_upgraders.simple_import import \
     upgrade_simple_import_1_to_2_and_rename
-from mitosheet.saved_analyses.step_upgraders.snowflake_import import (
-    upgrade_snowflake_import_1_to_2, upgrade_snowflake_import_2_to_3)
 from mitosheet.saved_analyses.step_upgraders.sort import upgrade_sort_1_to_2
-from mitosheet.saved_analyses.step_upgraders.utils_rename_column_headers import \
-    INITIAL_BULK_OLD_RENAME_STEP
-from mitosheet.step_performers.export_to_file import \
-    upgrade_export_to_file_1_to_2
-from mitosheet.transpiler.transpile_utils import get_default_code_options
-from mitosheet.types import CodeOptions
-from mitosheet.utils import is_prev_version
+from mitosheet.saved_analyses.step_upgraders.utils_rename_column_headers import (INITIAL_BULK_OLD_RENAME_STEP)
 
 """
 STEP_UPGRADES_FUNCTION_MAPPING mapping contains a mapping of all steps that need to be upgraded. A step
@@ -102,14 +79,10 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
     },
     'merge': {
         1: upgrade_merge_1_to_merge_2,
-        2: upgrade_merge_2_to_3,
-        3: upgrade_merge_3_to_4,
-        4: upgrade_merge_4_to_5
+        2: upgrade_merge_2_to_3
     },
     'change_column_dtype': {
-        1: upgrade_change_column_dtype_1_to_2,
-        2: upgrade_change_column_dtype_2_to_3,
-        3: upgrade_change_column_dtype_3_to_4
+        1: upgrade_change_column_dtype_1_to_2
     },
     'delete_column': {
         1: upgrade_delete_column_1_to_2,
@@ -122,10 +95,7 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
     'pivot': {
         3: upgrade_pivot_3_to_4,
         4: upgrade_pivot_4_to_5_and_rename,
-        5: upgrade_pivot_5_to_6,
-        6: upgrade_pivot_6_to_7,
-        7: upgrade_pivot_7_to_8,
-        8: upgrade_pivot_8_to_9
+        5: upgrade_pivot_5_to_6
     },
     'rename_column': {
         1: upgrade_rename_column_1_to_2
@@ -134,38 +104,10 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
         1: upgrade_reorder_column_1_to_2
     },
     'set_column_formula': {
-        1: upgrade_set_column_formula_1_to_2,
-        2: upgrade_set_column_formula_2_to_3,
-        3: upgrade_set_column_formula_3_to_4,
-        4: upgrade_set_column_formula_4_to_5
+        1: upgrade_set_column_formula_1_to_2
     },
     'sort': {
         1: upgrade_sort_1_to_2
-    },
-    'graph': {
-        1: upgrade_graph_1_to_2,
-        2: upgrade_graph_2_to_3,
-        3: upgrade_graph_3_to_4
-    },
-    'change_column_format': {
-        1: upgrade_change_column_format_1_to_remove
-    },
-    'set_dataframe_format': {
-        1: upgrade_set_dataframe_format_1_to_2
-    },
-    'excel_range_import': {
-        1: upgrade_excel_range_import_1_to_2,
-        2: upgrade_excel_range_import_2_to_3,
-        3: upgrade_excel_range_import_3_to_4,
-        4: upgrade_excel_range_import_4_to_5,
-        5: upgrade_excel_range_import_5_to_6
-    },
-    'snowflake_import': {
-        1: upgrade_snowflake_import_1_to_2,
-        2: upgrade_snowflake_import_2_to_3
-    },
-    'export_to_file': {
-        1: upgrade_export_to_file_1_to_2
     }
 }
 
@@ -333,76 +275,13 @@ def upgrade_steps_for_new_format(saved_analysis: Optional[Dict[str, Any]]) -> Op
         'steps_data': new_steps_data
     }
 
-def upgrade_saved_analysis_to_have_public_interface_version(saved_analysis: Optional[Dict[str, Any]], public_interface_version: Optional[int]) -> Optional[Dict[str, Any]]:
-
-    if saved_analysis is None:
-        return None
-    
-    # If there is already a public interface version, we just make sure to set it (as it was not carried through from previous ugprade
-    # functions which only take speciifc params
-    if public_interface_version is not None:
-        saved_analysis['public_interface_version'] = public_interface_version
-    else:
-        # Otherwise, we have to add it to the analysis as default 1
-        saved_analysis['public_interface_version'] = 1
-    
-    return saved_analysis
-
-def upgrade_saved_analysis_to_have_up_to_date_args(saved_analysis: Optional[Dict[str, Any]], args: List[str]) -> Optional[Dict[str, Any]]:
-    
-    if saved_analysis is None:
-        return None
-    
-    # We always add the args to the saved analysis, as they should be reset when you rerun an analysis
-    saved_analysis['args'] = args
-    
-    return saved_analysis
-
-def upgrade_saved_analysis_to_have_code(saved_analysis: Optional[Dict[str, Any]], code: Optional[str]) -> Optional[Dict[str, Any]]:
-
-    if saved_analysis is None:
-        return None
-    
-    if code is not None:
-        saved_analysis['code'] = code
-    else:
-        saved_analysis['code'] = None
-    
-    return saved_analysis
-
-def upgrade_saved_analysis_to_have_code_options(saved_analysis: Optional[Dict[str, Any]], analysis_name: str, code_options: Optional[CodeOptions]) -> Optional[Dict[str, Any]]:
-
-    if saved_analysis is None:
-        return None
-
-    if code_options is not None:
-        saved_analysis['code_options'] = code_options
-
-        # If the call function is not in the code options, we default it to True. 
-        # this param was added later
-        if 'call_function' not in code_options:
-            saved_analysis['code_options']['call_function'] = True
-
-        # If the import_custom_python_code is not in the code options, we default it to False. 
-        # this param was added later
-        if 'import_custom_python_code' not in code_options:
-            saved_analysis['code_options']['import_custom_python_code'] = False
-    else:
-        # Otherwise, we have to add it to the analysis as default 1
-        saved_analysis['code_options'] = get_default_code_options(analysis_name)
-
-    return saved_analysis
-
-def upgrade_saved_analysis_to_current_version(saved_analysis: Optional[Dict[str, Any]], analysis_name: str, args: List[str]) -> Optional[Dict[str, Any]]:
+def upgrade_saved_analysis_to_current_version(saved_analysis: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:
     """
     Upgrades a saved analysis to the current version.
     
     Notable, changes to the saved analysis take two types:
     1. Changes to the format of the saved analysis itself. 
     2. Changes to the format of the specific steps in the saved analysis.
-    3. Adds the public interface version and sets it to 1, if it's not already there (we also have to add to all steps)
-    4. Adds the args to the analysis so we can transpile functions in the future
-    5. Adds the code options to the analysis
 
     See mitosheet/upgrade/schemas.py, but as we only have 1 format change
     in the saved analyses, we process the specific step upgrades first if
@@ -410,23 +289,7 @@ def upgrade_saved_analysis_to_current_version(saved_analysis: Optional[Dict[str,
     """
     saved_analysis = upgrade_steps_for_old_format(saved_analysis)
     new_format_saved_analysis = upgrade_saved_analysis_format_to_steps_data(saved_analysis)
-    saved_analysis_with_new_step_format = upgrade_steps_for_new_format(new_format_saved_analysis)
-    saved_analysis_with_public_interface = upgrade_saved_analysis_to_have_public_interface_version(
-        saved_analysis_with_new_step_format, 
-        saved_analysis.get('public_interface_version', None) if saved_analysis is not None else None
-    )
-    saved_analysis_with_args = upgrade_saved_analysis_to_have_up_to_date_args(
-        saved_analysis_with_public_interface, 
-        args
-    )
-    saved_analysis_with_args_with_code = upgrade_saved_analysis_to_have_code(
-        saved_analysis_with_args,
-        saved_analysis.get('code', None) if saved_analysis is not None else None
-    )
-    saved_analysis_with_code_options = upgrade_saved_analysis_to_have_code_options(
-        saved_analysis_with_args_with_code,
-        analysis_name,
-        saved_analysis.get('code_options', None) if saved_analysis is not None else None,
-    )
+    saved_analysis = upgrade_steps_for_new_format(new_format_saved_analysis)
 
-    return saved_analysis_with_code_options
\ No newline at end of file
+    return saved_analysis
+    
\ No newline at end of file
