@@ -4,13 +4,12 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 
+from typing import Dict, List, Optional, Any
 import io
-from typing import Any, Dict, List, Optional
 
-import plotly.graph_objects as go
 
-from mitosheet.state import State
 from mitosheet.types import ColumnHeader
+import plotly.graph_objects as go
 
 # Graph types should be kept consistent with the GraphType in GraphSidebar.tsx
 SCATTER = "scatter"
@@ -39,6 +38,31 @@ GRAPH_TITLE_LABELS = {
 }
 
 
+def get_barmode(graph_type: str) -> Optional[str]:
+    """
+    Helper function for determing the barmode to apply to the graph creation function, depending
+    on the type of graph being created
+    """
+    if graph_type == BOX:
+        return "stack"
+    elif graph_type == HISTOGRAM:
+        return "group"
+    elif graph_type == BAR:
+        return "group"
+    else:
+        return None
+
+
+def create_parameter(param_key: str, param_value: str, format_as_string: bool) -> str:
+    """
+    Returns the params ready to be used in the transpiled code.
+    """
+    if format_as_string:
+        return f"{param_key}='{param_value}'"
+    else:
+        return f"{param_key}={param_value}"
+
+
 def get_graph_title(
     x_axis_column_headers: List[ColumnHeader],
     y_axis_column_headers: List[ColumnHeader],
@@ -69,14 +93,14 @@ def get_graph_title(
     return " ".join(graph_title_components)
 
 
-def get_new_graph_tab_name(graph_data_array: List[Dict[str, Any]]) -> str:
+def get_new_graph_tab_name(graph_data_dict: Dict[str, Dict[str, Any]]) -> str:
     """
     Creates the name for the new graph tab sheet using the format
     graph0, graph1, etc.
     """
     all_graph_names = []
-    for graph_data in graph_data_array:
-        all_graph_names.append(graph_data["graph_tab_name"])
+    for graph_data in graph_data_dict.values():
+        all_graph_names.append(graph_data["graphTabName"])
     
     graph_number_indicator = 0
     new_graph_name = f'graph{graph_number_indicator}'
@@ -87,19 +111,9 @@ def get_new_graph_tab_name(graph_data_array: List[Dict[str, Any]]) -> str:
         
     return new_graph_name
 
-def get_graph_index_by_graph_id(graph_data_array: List[Dict[str, Any]], graph_id: str) -> int:
-    """
-    Given a graph_id, returns the index of the graph_data_array that has that graph_id
-    """
-    for index, graph_data in enumerate(graph_data_array):
-        if "graph_id" in graph_data and graph_data["graph_id"] == graph_id:
-            return index
-
-    return -1
 
 def get_html_and_script_from_figure(
-    fig: go.Figure, height: str, width: str,
-    include_plotlyjs: bool,
+    fig: go.Figure, height: int, width: int
 ) -> Dict[str, str]:
     """
     Given a plotly figure, generates HTML from it, and returns
@@ -117,45 +131,23 @@ def get_html_and_script_from_figure(
     fig.write_html(
         buffer,
         full_html=False,
-        include_plotlyjs=include_plotlyjs,
+        include_plotlyjs=False,
         default_height=height,
         default_width=width,
     )
 
     original_html = buffer.getvalue()
+    # First, we remove the main div, and the resulting whitespace, to just have the children
+    original_html = original_html[5:]
+    original_html = original_html[:-6]
+    original_html = original_html.strip()
 
-
-    # Everything in a script tag we want to treat as one big script
-
-    # The get the graph div, which looks like: <div id="9c21d143-3fcd-4958-9295-ac7ada668186" class="plotly-graph-div" style="height:425px; width:970px;"></div>
-    # This is the only div we need to put on the frontend.
-    div = original_html[original_html.find('<div id='):original_html.find('</div>', original_html.find('<div id='))]
-
-    # Get all the scripts that are between the <script> tags, and join them together. If include_plotlyjs is true, this includes
-    # the plotly js script, and otherwise, it's just the data and the script that uses Plotly to build the graph on the div above
-    script = ''
-    index = 0
-    while index < len(original_html):
-        script_start = original_html.find('<script type="text/javascript">', index)
-        script_end = original_html.find('</script>', script_start)
-
-        if script_start == -1 or script_end == -1:
-            break
-
-        # Get rid of the initial script
-        script_start += len('<script type="text/javascript">')
-        script = script + original_html[script_start:script_end] + ';\n'
-        index = script_end + 9
+    # Then, we split the children into the div, and the script
+    # making sure to remove the script tag (so we can execute it)
+    script_start = '<script type="text/javascript">'
+    script_end = "</script>"
+    split_html = original_html.split(script_start)
+    div = split_html[0]
+    script = split_html[1][: -len(script_end)]
 
     return {"html": div, "script": script}
-
-def get_column_header_from_optional_column_id_graph_param(
-    state: State, 
-    graph_creation_params: Dict[str, Any], 
-    param_name: str
-) -> Optional[ColumnHeader]:
-    sheet_index = graph_creation_params['sheet_index']
-    if param_name in graph_creation_params.keys() and graph_creation_params[param_name] in state.column_ids.column_id_to_column_header[sheet_index].keys():
-        return state.column_ids.get_column_header_by_id(sheet_index, graph_creation_params[param_name])
-    else: return None
-
